==> libcamera-docs-0.0.3-3-x86_64.pkg.tar.zst: usr/share/doc/libcamera/api-html/search/all_6.js <==
var searchData=
[
  ['factories_0',['factories',['../classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase.html#a4cdf6349106ecb49a3b3ed9cdcd9f6c0',1,'libcamera::ipa::CameraSensorHelperFactoryBase::factories()'],['../classlibcamera_1_1PipelineHandlerFactoryBase.html#ad7616357a5b8d824f22713554a844ce5',1,'libcamera::PipelineHandlerFactoryBase::factories()'],['../classlibcamera_1_1ConverterFactoryBase.html#a4b8ef7e5270de11d84f05915bd8508c0',1,'libcamera::ConverterFactoryBase::factories()']]],
  ['fc_5fqueue_2eh_1',['fc_queue.h',['../fc__queue_8h.html',1,'']]],
  ['fcqueue_2',['FCQueue',['../classlibcamera_1_1ipa_1_1FCQueue.html#a04b07447b9ff942b5bdb35f22110876f',1,'libcamera::ipa::FCQueue::FCQueue()'],['../classlibcamera_1_1ipa_1_1FCQueue.html',1,'libcamera::ipa::FCQueue&lt; FrameContext &gt;']]],
  ['fcqueue_3c_20libcamera_3a_3aipa_3a_3aipu3_3a_3aipaframecontext_20_3e_3',['FCQueue&lt; libcamera::ipa::ipu3::IPAFrameContext &gt;',['../classlibcamera_1_1ipa_1_1FCQueue.html',1,'libcamera::ipa']]],
  ['fd_4',['fd',['../classlibcamera_1_1V4L2Device.html#a6b77845cf4b1eddcfc8fdeabf1795f82',1,'libcamera::V4L2Device::fd()'],['../classlibcamera_1_1Fence.html#a727b40eeec53c109922381e7eed610aa',1,'libcamera::Fence::fd()'],['../classlibcamera_1_1EventNotifier.html#a4160d70ec08b29913d5a4936dd57e0ba',1,'libcamera::EventNotifier::fd()'],['../structlibcamera_1_1FrameBuffer_1_1Plane.html#ac938f50358c7eb5ee656ec5bced0f537',1,'libcamera::FrameBuffer::Plane::fd()']]],
  ['fds_5',['fds',['../classlibcamera_1_1IPCMessage.html#a1ebcd1ddf091777ef34c12ebadc91da1',1,'libcamera::IPCMessage::fds() const'],['../classlibcamera_1_1IPCMessage.html#a049d7696716e0610643e1ee1d6b1496a',1,'libcamera::IPCMessage::fds()'],['../structlibcamera_1_1IPCUnixSocket_1_1Payload.html#a127fca44171a576af351fbb41520ffaf',1,'libcamera::IPCUnixSocket::Payload::fds()']]],
  ['fence_6',['Fence',['../classlibcamera_1_1Fence.html#ab84dac1ce57f0370012d6b278a99325a',1,'libcamera::Fence']]],
  ['fence_7',['fence',['../classlibcamera_1_1FrameBuffer_1_1Private.html#a673e4cda5a85fdbdf88b980e5e12226b',1,'libcamera::FrameBuffer::Private']]],
  ['fence_8',['Fence',['../classlibcamera_1_1Fence.html',1,'libcamera']]],
  ['fence_2eh_9',['fence.h',['../fence_8h.html',1,'']]],
  ['file_10',['File',['../classlibcamera_1_1File.html#abf5381b73abbd9be176c2691cd203314',1,'libcamera::File::File(const std::string &amp;name)'],['../classlibcamera_1_1File.html#aa47651dbd19d4a39ccd1aedebe661b7f',1,'libcamera::File::File()'],['../classlibcamera_1_1File.html',1,'libcamera::File']]],
  ['file_2eh_11',['file.h',['../file_8h.html',1,'']]],
  ['fileinfo_12',['fileInfo',['../classlibcamera_1_1LogMessage.html#a810d727f0f0fb333b8ab5e3c1624bba9',1,'libcamera::LogMessage']]],
  ['filename_13',['fileName',['../classlibcamera_1_1File.html#a387e2f92eb36a45aad031915ca90471a',1,'libcamera::File']]],
  ['fillparamsbuffer_14',['fillParamsBuffer',['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a8f29b92f4ac52ce3e3ca3c5a64ddbd49',1,'libcamera::ipa::ipu3::IPAIPU3']]],
  ['find_15',['find',['../classlibcamera_1_1ControlInfoMap.html#a7d5d2891e3c6f24929a769499df98c5d',1,'libcamera::ControlInfoMap::find(unsigned int key)'],['../classlibcamera_1_1ControlInfoMap.html#abadd15c7dce8945717d2b6918d78c7b2',1,'libcamera::ControlInfoMap::find(unsigned int key) const']]],
  ['findbuffer_16',['findBuffer',['../classlibcamera_1_1Request.html#abaed06e43f6a92590075962f825767f7',1,'libcamera::Request']]],
  ['finished_17',['finished',['../classlibcamera_1_1Thread.html#a7f3bdc2840090cfb00fa8442ce36c3df',1,'libcamera::Thread::finished()'],['../classlibcamera_1_1Process.html#a91e787bf85a26caf470d19c759a127a2',1,'libcamera::Process::finished()']]],
  ['firmwarenodepath_18',['firmwareNodePath',['../sysfs_8h.html#a812399a5a062d9bf229e181432843546',1,'libcamera::sysfs']]],
  ['flags_19',['Flags',['../classlibcamera_1_1Flags.html#aac499f77c245c6e3ca29e5d38b5806df',1,'libcamera::Flags']]],
  ['flags_20',['flags',['../classlibcamera_1_1MediaEntity.html#a48322351941cc87e2ac72b3175cbc561',1,'libcamera::MediaEntity']]],
  ['flags_21',['Flags',['../classlibcamera_1_1Flags.html#a9ce65ae409e2d79fcb8fcbce4d3c5b6b',1,'libcamera::Flags']]],
  ['flags_22',['flags',['../classlibcamera_1_1MediaLink.html#ac238dd3d10500d8536a6d356d06b2521',1,'libcamera::MediaLink::flags()'],['../classlibcamera_1_1MediaPad.html#a5bc5fa9cb6ebc11aa8f541cf8c5c4f65',1,'libcamera::MediaPad::flags()']]],
  ['flags_23',['Flags',['../classlibcamera_1_1Flags.html',1,'libcamera']]],
  ['flags_2eh_24',['flags.h',['../flags_8h.html',1,'']]],
  ['flags_3c_20openmodeflag_20_3e_25',['Flags&lt; OpenModeFlag &gt;',['../classlibcamera_1_1Flags.html',1,'libcamera']]],
  ['focus_26',['focus',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a2962804bbee637f7a70930b427ae19f6',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['focusfom_27',['FocusFoM',['../namespacelibcamera_1_1controls.html#a3c5f034588ba57aaeb4d0d79ce0735e2',1,'libcamera::controls']]],
  ['focuslens_28',['focusLens',['../classlibcamera_1_1CameraSensor.html#ace4fc704dc507213d9cd13d3ecebd5b5',1,'libcamera::CameraSensor']]],
  ['format_29',['format',['../classlibcamera_1_1PixelFormatInfo.html#a26a938c3d1967e062fc20ec8df9c54b3',1,'libcamera::PixelFormatInfo::format()'],['../structlibcamera_1_1V4L2PixelFormat_1_1Info.html#ae708692eb9ed99c8dd5473d690f86436',1,'libcamera::V4L2PixelFormat::Info::format()']]],
  ['formats_30',['formats',['../structlibcamera_1_1StreamConfiguration.html#a37725e6b9e179ca80be0e57ed97857d3',1,'libcamera::StreamConfiguration::formats()'],['../classlibcamera_1_1V4L2VideoDevice.html#adc347c736d39fc4029907b47f0ac8a8b',1,'libcamera::V4L2VideoDevice::formats()'],['../classlibcamera_1_1V4L2Subdevice.html#a7c665ec2c10614144cd97ba3609cc04d',1,'libcamera::V4L2Subdevice::formats()'],['../classlibcamera_1_1V4L2M2MConverter.html#ad2ecddf6be60471976cf7f0ecc523ac4',1,'libcamera::V4L2M2MConverter::formats()'],['../classlibcamera_1_1Converter.html#a66f89e1dbc69da4aaf6c3a490fce26e4',1,'libcamera::Converter::formats()']]],
  ['formats_31',['Formats',['../classlibcamera_1_1V4L2VideoDevice.html#a028e21c214bae36abe9af7a1a95c991b',1,'libcamera::V4L2VideoDevice::Formats()'],['../classlibcamera_1_1V4L2Subdevice.html#a7d9d89369b43ec42f094ef7238639109',1,'libcamera::V4L2Subdevice::Formats()']]],
  ['formats_2eh_32',['formats.h',['../libcamera_2include_2libcamera_2internal_2formats_8h.html',1,'']]],
  ['fourcc_33',['fourcc',['../classlibcamera_1_1V4L2DeviceFormat.html#a1d9f472f571be3791f70e4cf44daae82',1,'libcamera::V4L2DeviceFormat::fourcc()'],['../classlibcamera_1_1V4L2PixelFormat.html#a79d3f70a7b907efae0804751ef054748',1,'libcamera::V4L2PixelFormat::fourcc()'],['../classlibcamera_1_1PixelFormat.html#ad2a53a4a70756f31280d386550de5f05',1,'libcamera::PixelFormat::fourcc()']]],
  ['framebuffer_34',['FrameBuffer',['../classlibcamera_1_1FrameBuffer.html#a86db89fb9e428357ab05bf71ae72c421',1,'libcamera::FrameBuffer::FrameBuffer(const std::vector&lt; Plane &gt; &amp;planes, unsigned int cookie=0)'],['../classlibcamera_1_1FrameBuffer.html#af5b65931df6a8354f8bb2d932e0b1d72',1,'libcamera::FrameBuffer::FrameBuffer(std::unique_ptr&lt; Private &gt; d)'],['../classlibcamera_1_1FrameBuffer.html',1,'libcamera::FrameBuffer']]],
  ['framebuffer_2eh_35',['framebuffer.h',['../framebuffer_8h.html',1,'(Global Namespace)'],['../internal_2framebuffer_8h.html',1,'(Global Namespace)']]],
  ['framebuffer_5fallocator_2eh_36',['framebuffer_allocator.h',['../framebuffer__allocator_8h.html',1,'']]],
  ['framebufferallocator_37',['FrameBufferAllocator',['../classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597',1,'libcamera::FrameBufferAllocator::FrameBufferAllocator()'],['../classlibcamera_1_1FrameBufferAllocator.html',1,'libcamera::FrameBufferAllocator']]],
  ['framecancelled_38',['FrameCancelled',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a1ca4a9a1fbd6225f498e4ab942da1ce4',1,'libcamera::FrameMetadata']]],
  ['framecontext_39',['FrameContext',['../classlibcamera_1_1ipa_1_1Module.html#a5a1bf7efd7811fb9da8ff311aeef3b1c',1,'libcamera::ipa::Module::FrameContext()'],['../structlibcamera_1_1ipa_1_1FrameContext.html',1,'libcamera::ipa::FrameContext']]],
  ['framecontexts_40',['frameContexts',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html#a7052224a7a5dbb0ef824d4fc1e939916',1,'libcamera::ipa::ipu3::IPAContext']]],
  ['frameduration_41',['FrameDuration',['../namespacelibcamera_1_1controls.html#a37d99a76c7249c143beecd70917469be',1,'libcamera::controls']]],
  ['framedurationlimits_42',['FrameDurationLimits',['../namespacelibcamera_1_1controls.html#a4f3236ff99d40a3a44fcd1ad77c4458f',1,'libcamera::controls']]],
  ['frameerror_43',['FrameError',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a7c1aeab00983653a779208f2726e9a83',1,'libcamera::FrameMetadata']]],
  ['framemetadata_44',['FrameMetadata',['../structlibcamera_1_1FrameMetadata.html',1,'libcamera']]],
  ['framesize_45',['frameSize',['../classlibcamera_1_1PixelFormatInfo.html#a06399e845afd406ce55cc6f1428c0742',1,'libcamera::PixelFormatInfo::frameSize()'],['../structlibcamera_1_1StreamConfiguration.html#adb91542e49bac6509e757c1f8774b923',1,'libcamera::StreamConfiguration::frameSize()'],['../classlibcamera_1_1PixelFormatInfo.html#aa98fc36a8238e5fbb426089dddef273d',1,'libcamera::PixelFormatInfo::frameSize()']]],
  ['framestart_46',['frameStart',['../classlibcamera_1_1V4L2Device.html#a57ed50c44d1cd5c2cedab9b42e087e6c',1,'libcamera::V4L2Device']]],
  ['framesuccess_47',['FrameSuccess',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846af31d76e864a0067eddc5cf96cfcfca1d',1,'libcamera::FrameMetadata']]],
  ['free_48',['free',['../classlibcamera_1_1FrameBufferAllocator.html#a184749ea64aeba195bd7c8a880311cd4',1,'libcamera::FrameBufferAllocator']]],
  ['fromcolorspace_49',['fromColorSpace',['../classlibcamera_1_1V4L2Device.html#a3b2d0bf205d45b91c6945018e92f3933',1,'libcamera::V4L2Device']]],
  ['fromentityname_50',['fromEntityName',['../classlibcamera_1_1V4L2VideoDevice.html#aa9c5f20a82893665448ca8c22f184217',1,'libcamera::V4L2VideoDevice::fromEntityName()'],['../classlibcamera_1_1V4L2Subdevice.html#a35a7e3645918e7694c371a77ad5c3f64',1,'libcamera::V4L2Subdevice::fromEntityName()']]],
  ['frommbuscode_51',['fromMbusCode',['../classlibcamera_1_1BayerFormat.html#a9b2b5c89ed37fc349f9d2ddec03cb7cc',1,'libcamera::BayerFormat']]],
  ['frompixelformat_52',['fromPixelFormat',['../classlibcamera_1_1BayerFormat.html#ad0b858a59e3d158e624b43aae6c98254',1,'libcamera::BayerFormat::fromPixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a9aaf2bb126d0308de1b2b4ded55be4b1',1,'libcamera::V4L2PixelFormat::fromPixelFormat()']]],
  ['fromstring_53',['fromString',['../classlibcamera_1_1ColorSpace.html#a15ab4ed7e77f779a155be467a30ad495',1,'libcamera::ColorSpace::fromString()'],['../classlibcamera_1_1PixelFormat.html#a39a0a637e77fa8f9f86fad3e0c5771f6',1,'libcamera::PixelFormat::fromString()']]],
  ['fromv4l2pixelformat_54',['fromV4L2PixelFormat',['../classlibcamera_1_1BayerFormat.html#a00f274e814cfa0e7915c6f9687804cb1',1,'libcamera::BayerFormat']]],
  ['full_55',['Full',['../classlibcamera_1_1ColorSpace.html#ad3dd58d644ebcee4201886e4619f118fabbd47109890259c0127154db1af26c75',1,'libcamera::ColorSpace']]],
  ['function_56',['function',['../classlibcamera_1_1MediaEntity.html#a6078dab1b3beaf6b0917babdab001fbd',1,'libcamera::MediaEntity']]]
];

==> libcamera-docs-0.0.4-4-x86_64.pkg.tar.zst: usr/share/doc/libcamera/api-html/search/all_6.js <==
var searchData=
[
  ['factories_0',['factories',['../classlibcamera_1_1ipa_1_1CameraSensorHelperFactoryBase.html#a4cdf6349106ecb49a3b3ed9cdcd9f6c0',1,'libcamera::ipa::CameraSensorHelperFactoryBase::factories()'],['../classlibcamera_1_1PipelineHandlerFactoryBase.html#ad7616357a5b8d824f22713554a844ce5',1,'libcamera::PipelineHandlerFactoryBase::factories()'],['../classlibcamera_1_1ConverterFactoryBase.html#a4b8ef7e5270de11d84f05915bd8508c0',1,'libcamera::ConverterFactoryBase::factories()']]],
  ['fc_5fqueue_2eh_1',['fc_queue.h',['../fc__queue_8h.html',1,'']]],
  ['fcqueue_2',['FCQueue',['../classlibcamera_1_1ipa_1_1FCQueue.html#a04b07447b9ff942b5bdb35f22110876f',1,'libcamera::ipa::FCQueue::FCQueue()'],['../classlibcamera_1_1ipa_1_1FCQueue.html',1,'libcamera::ipa::FCQueue&lt; FrameContext &gt;']]],
  ['fcqueue_3c_20libcamera_3a_3aipa_3a_3aipu3_3a_3aipaframecontext_20_3e_3',['FCQueue&lt; libcamera::ipa::ipu3::IPAFrameContext &gt;',['../classlibcamera_1_1ipa_1_1FCQueue.html',1,'libcamera::ipa']]],
  ['fd_4',['fd',['../classlibcamera_1_1V4L2Device.html#a6b77845cf4b1eddcfc8fdeabf1795f82',1,'libcamera::V4L2Device::fd()'],['../classlibcamera_1_1Fence.html#a727b40eeec53c109922381e7eed610aa',1,'libcamera::Fence::fd()'],['../classlibcamera_1_1EventNotifier.html#a4160d70ec08b29913d5a4936dd57e0ba',1,'libcamera::EventNotifier::fd()'],['../structlibcamera_1_1FrameBuffer_1_1Plane.html#ac938f50358c7eb5ee656ec5bced0f537',1,'libcamera::FrameBuffer::Plane::fd()']]],
  ['fds_5',['fds',['../classlibcamera_1_1IPCMessage.html#a1ebcd1ddf091777ef34c12ebadc91da1',1,'libcamera::IPCMessage::fds() const'],['../classlibcamera_1_1IPCMessage.html#a049d7696716e0610643e1ee1d6b1496a',1,'libcamera::IPCMessage::fds()'],['../structlibcamera_1_1IPCUnixSocket_1_1Payload.html#a127fca44171a576af351fbb41520ffaf',1,'libcamera::IPCUnixSocket::Payload::fds()']]],
  ['fence_6',['Fence',['../classlibcamera_1_1Fence.html#ab84dac1ce57f0370012d6b278a99325a',1,'libcamera::Fence']]],
  ['fence_7',['fence',['../classlibcamera_1_1FrameBuffer_1_1Private.html#a673e4cda5a85fdbdf88b980e5e12226b',1,'libcamera::FrameBuffer::Private']]],
  ['fence_8',['Fence',['../classlibcamera_1_1Fence.html',1,'libcamera']]],
  ['fence_2eh_9',['fence.h',['../fence_8h.html',1,'']]],
  ['file_10',['File',['../classlibcamera_1_1File.html#abf5381b73abbd9be176c2691cd203314',1,'libcamera::File::File(const std::string &amp;name)'],['../classlibcamera_1_1File.html#aa47651dbd19d4a39ccd1aedebe661b7f',1,'libcamera::File::File()'],['../classlibcamera_1_1File.html',1,'libcamera::File']]],
  ['file_2eh_11',['file.h',['../file_8h.html',1,'']]],
  ['fileinfo_12',['fileInfo',['../classlibcamera_1_1LogMessage.html#a810d727f0f0fb333b8ab5e3c1624bba9',1,'libcamera::LogMessage']]],
  ['filename_13',['fileName',['../classlibcamera_1_1File.html#a387e2f92eb36a45aad031915ca90471a',1,'libcamera::File']]],
  ['fillparamsbuffer_14',['fillParamsBuffer',['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a8f29b92f4ac52ce3e3ca3c5a64ddbd49',1,'libcamera::ipa::ipu3::IPAIPU3']]],
  ['find_15',['find',['../classlibcamera_1_1ControlInfoMap.html#a7d5d2891e3c6f24929a769499df98c5d',1,'libcamera::ControlInfoMap::find(unsigned int key)'],['../classlibcamera_1_1ControlInfoMap.html#abadd15c7dce8945717d2b6918d78c7b2',1,'libcamera::ControlInfoMap::find(unsigned int key) const']]],
  ['findbuffer_16',['findBuffer',['../classlibcamera_1_1Request.html#abaed06e43f6a92590075962f825767f7',1,'libcamera::Request']]],
  ['finished_17',['finished',['../classlibcamera_1_1Thread.html#a7f3bdc2840090cfb00fa8442ce36c3df',1,'libcamera::Thread::finished()'],['../classlibcamera_1_1Process.html#a91e787bf85a26caf470d19c759a127a2',1,'libcamera::Process::finished()']]],
  ['firmwarenodepath_18',['firmwareNodePath',['../sysfs_8h.html#a812399a5a062d9bf229e181432843546',1,'libcamera::sysfs']]],
  ['flags_19',['Flags',['../classlibcamera_1_1Flags.html#aac499f77c245c6e3ca29e5d38b5806df',1,'libcamera::Flags']]],
  ['flags_20',['flags',['../classlibcamera_1_1MediaEntity.html#a48322351941cc87e2ac72b3175cbc561',1,'libcamera::MediaEntity']]],
  ['flags_21',['Flags',['../classlibcamera_1_1Flags.html#a9ce65ae409e2d79fcb8fcbce4d3c5b6b',1,'libcamera::Flags']]],
  ['flags_22',['flags',['../classlibcamera_1_1MediaLink.html#ac238dd3d10500d8536a6d356d06b2521',1,'libcamera::MediaLink::flags()'],['../classlibcamera_1_1MediaPad.html#a5bc5fa9cb6ebc11aa8f541cf8c5c4f65',1,'libcamera::MediaPad::flags()']]],
  ['flags_23',['Flags',['../classlibcamera_1_1Flags.html',1,'libcamera']]],
  ['flags_2eh_24',['flags.h',['../flags_8h.html',1,'']]],
  ['flags_3c_20openmodeflag_20_3e_25',['Flags&lt; OpenModeFlag &gt;',['../classlibcamera_1_1Flags.html',1,'libcamera']]],
  ['focus_26',['focus',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a2962804bbee637f7a70930b427ae19f6',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['focusfom_27',['FocusFoM',['../namespacelibcamera_1_1controls.html#a3c5f034588ba57aaeb4d0d79ce0735e2',1,'libcamera::controls']]],
  ['focuslens_28',['focusLens',['../classlibcamera_1_1CameraSensor.html#ace4fc704dc507213d9cd13d3ecebd5b5',1,'libcamera::CameraSensor']]],
  ['format_29',['format',['../classlibcamera_1_1PixelFormatInfo.html#a26a938c3d1967e062fc20ec8df9c54b3',1,'libcamera::PixelFormatInfo::format()'],['../structlibcamera_1_1V4L2PixelFormat_1_1Info.html#ae708692eb9ed99c8dd5473d690f86436',1,'libcamera::V4L2PixelFormat::Info::format()']]],
  ['formats_30',['Formats',['../classlibcamera_1_1V4L2VideoDevice.html#a028e21c214bae36abe9af7a1a95c991b',1,'libcamera::V4L2VideoDevice::Formats()'],['../classlibcamera_1_1V4L2Subdevice.html#a7d9d89369b43ec42f094ef7238639109',1,'libcamera::V4L2Subdevice::Formats()']]],
  ['formats_31',['formats',['../structlibcamera_1_1StreamConfiguration.html#a37725e6b9e179ca80be0e57ed97857d3',1,'libcamera::StreamConfiguration::formats()'],['../classlibcamera_1_1V4L2VideoDevice.html#adc347c736d39fc4029907b47f0ac8a8b',1,'libcamera::V4L2VideoDevice::formats()'],['../classlibcamera_1_1V4L2Subdevice.html#a7c665ec2c10614144cd97ba3609cc04d',1,'libcamera::V4L2Subdevice::formats()'],['../classlibcamera_1_1V4L2M2MConverter.html#ad2ecddf6be60471976cf7f0ecc523ac4',1,'libcamera::V4L2M2MConverter::formats()'],['../classlibcamera_1_1Converter.html#a66f89e1dbc69da4aaf6c3a490fce26e4',1,'libcamera::Converter::formats()']]],
  ['formats_2eh_32',['formats.h',['../libcamera_2include_2libcamera_2internal_2formats_8h.html',1,'']]],
  ['fourcc_33',['fourcc',['../classlibcamera_1_1V4L2DeviceFormat.html#a1d9f472f571be3791f70e4cf44daae82',1,'libcamera::V4L2DeviceFormat::fourcc()'],['../classlibcamera_1_1V4L2PixelFormat.html#a79d3f70a7b907efae0804751ef054748',1,'libcamera::V4L2PixelFormat::fourcc()'],['../classlibcamera_1_1PixelFormat.html#ad2a53a4a70756f31280d386550de5f05',1,'libcamera::PixelFormat::fourcc()']]],
  ['framebuffer_34',['FrameBuffer',['../classlibcamera_1_1FrameBuffer.html#a86db89fb9e428357ab05bf71ae72c421',1,'libcamera::FrameBuffer::FrameBuffer(const std::vector&lt; Plane &gt; &amp;planes, unsigned int cookie=0)'],['../classlibcamera_1_1FrameBuffer.html#af5b65931df6a8354f8bb2d932e0b1d72',1,'libcamera::FrameBuffer::FrameBuffer(std::unique_ptr&lt; Private &gt; d)'],['../classlibcamera_1_1FrameBuffer.html',1,'libcamera::FrameBuffer']]],
  ['framebuffer_2eh_35',['framebuffer.h',['../internal_2framebuffer_8h.html',1,'(Global Namespace)'],['../framebuffer_8h.html',1,'(Global Namespace)']]],
  ['framebuffer_5fallocator_2eh_36',['framebuffer_allocator.h',['../framebuffer__allocator_8h.html',1,'']]],
  ['framebufferallocator_37',['FrameBufferAllocator',['../classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597',1,'libcamera::FrameBufferAllocator::FrameBufferAllocator()'],['../classlibcamera_1_1FrameBufferAllocator.html',1,'libcamera::FrameBufferAllocator']]],
  ['framecancelled_38',['FrameCancelled',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a1ca4a9a1fbd6225f498e4ab942da1ce4',1,'libcamera::FrameMetadata']]],
  ['framecontext_39',['FrameContext',['../classlibcamera_1_1ipa_1_1Module.html#a5a1bf7efd7811fb9da8ff311aeef3b1c',1,'libcamera::ipa::Module::FrameContext()'],['../structlibcamera_1_1ipa_1_1FrameContext.html',1,'libcamera::ipa::FrameContext']]],
  ['framecontexts_40',['frameContexts',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html#a7052224a7a5dbb0ef824d4fc1e939916',1,'libcamera::ipa::ipu3::IPAContext']]],
  ['frameduration_41',['FrameDuration',['../namespacelibcamera_1_1controls.html#a37d99a76c7249c143beecd70917469be',1,'libcamera::controls']]],
  ['framedurationlimits_42',['FrameDurationLimits',['../namespacelibcamera_1_1controls.html#a4f3236ff99d40a3a44fcd1ad77c4458f',1,'libcamera::controls']]],
  ['frameerror_43',['FrameError',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846a7c1aeab00983653a779208f2726e9a83',1,'libcamera::FrameMetadata']]],
  ['framemetadata_44',['FrameMetadata',['../structlibcamera_1_1FrameMetadata.html',1,'libcamera']]],
  ['framesize_45',['frameSize',['../classlibcamera_1_1PixelFormatInfo.html#a06399e845afd406ce55cc6f1428c0742',1,'libcamera::PixelFormatInfo::frameSize()'],['../structlibcamera_1_1StreamConfiguration.html#adb91542e49bac6509e757c1f8774b923',1,'libcamera::StreamConfiguration::frameSize()'],['../classlibcamera_1_1PixelFormatInfo.html#aa98fc36a8238e5fbb426089dddef273d',1,'libcamera::PixelFormatInfo::frameSize()']]],
  ['framestart_46',['frameStart',['../classlibcamera_1_1V4L2Device.html#a57ed50c44d1cd5c2cedab9b42e087e6c',1,'libcamera::V4L2Device']]],
  ['framesuccess_47',['FrameSuccess',['../structlibcamera_1_1FrameMetadata.html#a0ba5ab50b5169a1d94f6963c429c9846af31d76e864a0067eddc5cf96cfcfca1d',1,'libcamera::FrameMetadata']]],
  ['free_48',['free',['../classlibcamera_1_1FrameBufferAllocator.html#a184749ea64aeba195bd7c8a880311cd4',1,'libcamera::FrameBufferAllocator']]],
  ['fromcolorspace_49',['fromColorSpace',['../classlibcamera_1_1V4L2Device.html#a3b2d0bf205d45b91c6945018e92f3933',1,'libcamera::V4L2Device']]],
  ['fromentityname_50',['fromEntityName',['../classlibcamera_1_1V4L2VideoDevice.html#aa9c5f20a82893665448ca8c22f184217',1,'libcamera::V4L2VideoDevice::fromEntityName()'],['../classlibcamera_1_1V4L2Subdevice.html#a35a7e3645918e7694c371a77ad5c3f64',1,'libcamera::V4L2Subdevice::fromEntityName()']]],
  ['frommbuscode_51',['fromMbusCode',['../classlibcamera_1_1BayerFormat.html#a9b2b5c89ed37fc349f9d2ddec03cb7cc',1,'libcamera::BayerFormat']]],
  ['frompixelformat_52',['fromPixelFormat',['../classlibcamera_1_1BayerFormat.html#ad0b858a59e3d158e624b43aae6c98254',1,'libcamera::BayerFormat::fromPixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a9aaf2bb126d0308de1b2b4ded55be4b1',1,'libcamera::V4L2PixelFormat::fromPixelFormat()']]],
  ['fromstring_53',['fromString',['../classlibcamera_1_1ColorSpace.html#a15ab4ed7e77f779a155be467a30ad495',1,'libcamera::ColorSpace::fromString()'],['../classlibcamera_1_1PixelFormat.html#a39a0a637e77fa8f9f86fad3e0c5771f6',1,'libcamera::PixelFormat::fromString()']]],
  ['fromv4l2pixelformat_54',['fromV4L2PixelFormat',['../classlibcamera_1_1BayerFormat.html#a00f274e814cfa0e7915c6f9687804cb1',1,'libcamera::BayerFormat']]],
  ['full_55',['Full',['../classlibcamera_1_1ColorSpace.html#ad3dd58d644ebcee4201886e4619f118fabbd47109890259c0127154db1af26c75',1,'libcamera::ColorSpace']]],
  ['function_56',['function',['../classlibcamera_1_1MediaEntity.html#a6078dab1b3beaf6b0917babdab001fbd',1,'libcamera::MediaEntity']]]
];
